# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asvprotobuf/std.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='asvprotobuf/std.proto',
  package='asvprotobuf.std',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x15\x61svprotobuf/std.proto\x12\x0f\x61svprotobuf.std\"+\n\tTimestamp\x12\x0f\n\x07seconds\x18\x01 \x01(\x03\x12\r\n\x05nanos\x18\x02 \x01(\x05\"E\n\x06Header\x12)\n\x05stamp\x18\x01 \x01(\x0b\x32\x1a.asvprotobuf.std.Timestamp\x12\x10\n\x08\x66rame_id\x18\x0f \x01(\t\"7\n\x0bOrientation\x12\x0c\n\x04roll\x18\x0f \x01(\x01\x12\r\n\x05pitch\x18\x10 \x01(\x01\x12\x0b\n\x03yaw\x18\x11 \x01(\x01\")\n\x06Vector\x12\t\n\x01x\x18\x0f \x01(\x01\x12\t\n\x01y\x18\x10 \x01(\x01\x12\t\n\x01z\x18\x11 \x01(\x01\x62\x06proto3')
)




_TIMESTAMP = _descriptor.Descriptor(
  name='Timestamp',
  full_name='asvprotobuf.std.Timestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='asvprotobuf.std.Timestamp.seconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nanos', full_name='asvprotobuf.std.Timestamp.nanos', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=85,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='asvprotobuf.std.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='asvprotobuf.std.Header.stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='asvprotobuf.std.Header.frame_id', index=1,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=156,
)


_ORIENTATION = _descriptor.Descriptor(
  name='Orientation',
  full_name='asvprotobuf.std.Orientation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='roll', full_name='asvprotobuf.std.Orientation.roll', index=0,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pitch', full_name='asvprotobuf.std.Orientation.pitch', index=1,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yaw', full_name='asvprotobuf.std.Orientation.yaw', index=2,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=213,
)


_VECTOR = _descriptor.Descriptor(
  name='Vector',
  full_name='asvprotobuf.std.Vector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='asvprotobuf.std.Vector.x', index=0,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='asvprotobuf.std.Vector.y', index=1,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='asvprotobuf.std.Vector.z', index=2,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=256,
)

_HEADER.fields_by_name['stamp'].message_type = _TIMESTAMP
DESCRIPTOR.message_types_by_name['Timestamp'] = _TIMESTAMP
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Orientation'] = _ORIENTATION
DESCRIPTOR.message_types_by_name['Vector'] = _VECTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Timestamp = _reflection.GeneratedProtocolMessageType('Timestamp', (_message.Message,), dict(
  DESCRIPTOR = _TIMESTAMP,
  __module__ = 'asvprotobuf.std_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.std.Timestamp)
  ))
_sym_db.RegisterMessage(Timestamp)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
  DESCRIPTOR = _HEADER,
  __module__ = 'asvprotobuf.std_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.std.Header)
  ))
_sym_db.RegisterMessage(Header)

Orientation = _reflection.GeneratedProtocolMessageType('Orientation', (_message.Message,), dict(
  DESCRIPTOR = _ORIENTATION,
  __module__ = 'asvprotobuf.std_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.std.Orientation)
  ))
_sym_db.RegisterMessage(Orientation)

Vector = _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), dict(
  DESCRIPTOR = _VECTOR,
  __module__ = 'asvprotobuf.std_pb2'
  # @@protoc_insertion_point(class_scope:asvprotobuf.std.Vector)
  ))
_sym_db.RegisterMessage(Vector)


# @@protoc_insertion_point(module_scope)
